bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 8. Aventiure
___________________________________________________ #### Aventivre wie sifrit nah den nibelvngen #### sinen rechen fvor
###### 482 | ### Dannen gie do sifrit | cer porten vf den sant ### in siner tarnkappen | da er ein schiffel vant ### daran so stvnt vil tovgen | sigemvndes chint ### er fvrt ez balde dannen | alsam ez wete der wint
###### 483 | ### den schefmeister sach niemen | daz schiffel sere vloz ### von sifrides crepften | di waren also groz ### si wanden daz ez fvrte | ein svnder starcher wint ### nein ez fvrte sifrit | der schonen sigelinden chint
###### 484 | ### bi des tages citen | vnt in der einen naht ### chom er ce einem lande | mit grozlicher maht ### wol hvndert langer raste | vnt dan noch paz ### di hiezen nibelvnge | da er den grozen shaz besaz
###### 485 | ### der helt der fvr aleine | vf einen wert vil breit ### daz shif gebant vil balde | der ritter vil gemeit ### er gie zv einem berge | darvf ein bvrch stvnt ### vnt svchte herberge | so di wegemveden tvnt
###### 486 | ### do chom er fvr di porten | verslozzen im div stvnt ### ia hvten si ir eren | so noch di livte tvnt ### anz tor begvnde bozen | der vnchvnde man ### daz was wol behivtet | do vant er innerthalben stan
###### 487 | ### einen vngefvegen | der der bvrge pflach ### bi dem zallen citen | sin geweffen lach ### der sprach wer ist der bozet | so vaste an daz tor ### do wandelt sine stimme | der herre sifrit davor
###### 488 | ### er sprach ich pin ein recke | nvo entslivz vf daz tor ### ich erzvorne ir etslichen | noch hivte davor ### der gerne sampfte laege | vnt hete sin gemach ### daz mvete den portnaere | do daz her sifrit gesprach
###### 489 | ### nv hete der rise chvene | sin gewaeffen angetan ### sinen helm vf sin hovbt | der vil starche man ### den schilt vil balde zvhte | daz tor er vf do swief ### wi reht grimmechlichen | er an sifriden lief
###### 490 | ### wi er getorste wechen | so manigen chvenen man ### da wurden slege swinde | von siner hant getan ### do begond im shaermen | der herliche gast ### do shvf der portnaere | daz sin gespenge cebrast
###### 491 | ### von einer isenstangen | des gie dem helde not ### ein teil begonde fvrhten | sifrit den tot ### do der portnaere | so crepftechliche slvch ### darvmbe was im waege | sin herre sifrit genvch
###### 492 | ### si striten also sere | daz al div bvrch ershal ### do hort man daz diezen | in nibelvnges sal ### er twanch den portnaere | daz er in sit gebant ### div mere wurden chvnde | in al nibelvnge lant
###### 493 | ### do hort daz grimme striten | verre dvrch den berch ### albrich der vil chvene | ein wildiz getwerch ### er waffende sich balde | do lief er da er vant ### disen gast vil edelen | da er den risen gebant
###### 494 | ### albrich was vil grimme | starch was er genvch ### helm vnd ringe | er an dem libe trvch ### vnt eine geisel swaere | von golde an siner hant ### do lief er harte snelle | da er sifriden vant
###### 495 | ### siben chnoffe swaere | di hiengen vor daran ### damit er vmb der hende | den schilt dem chvenem man ### slvch so pitterlichen | daz im des vil cebrast ### des libes chom in sorge | do der waetliche gast
###### 496 | ### den sherm er vor der hende | gar cebrochen swanch ### do stiez er in di sheiden | ein waffen daz was lanch ### den sinen chameraere | wold er niht slahen tot ### er shonte siner zvehte | als im div tvgent daz gebot
###### 497 | ### mit starchen sinen handen | lief er albrichen an ### do viench er bi dem parte | den altgrisen man ### er zogten vngefvege | daez er lvte schre ### zvht des ivngen heldes | div tet albriche we
###### 498 | ### lvte rief der chvene | lat mich genesen ### vnt moeht ich iemens eigen | an einen recken wesen ### dem swure ich des eide | ich waer im vndertan ### ich dient iv e ich stverbe | sprach der listige man
###### 499 | ### er bant ovch albrichen | alsam den risen e ### di sifrides creffte | taten im vil we ### daz getwerch begonde vragen | wi sit ir genant ### er sprach ich haeize sifrit | ich wand ich waer iv wol bechant
###### 500 | ### so wol mich dirre maere | sprach albrich daz getwerch ### nv han ich wol erfvnden | div degenlichen werch ### daz ir von waren shvlden | mvegt landes herre wesen ### ich tvn swaz ir gebietet | daz ir mich lazet genesin
###### 501 | ### do sprach der herre sifrit | ir svlt balde gan ### vnt bringet mir der rechen | der besten di wir han ### tvsent nibelvnge | daz mich di hi gesehen ### warvmbe er do des gerte | des hort in niemen veriehen
###### 502 | ### dem risen vnt albriche | loset er div bant ### do lief albrich balde | da er di recken vant ### er wachete sorgende | der nibelvnge man ### er sprach wol vf ir helde | ir svlt ce sifride gan
###### 503 | ### si sprvngen von den betten | vnt waren vil bereit ### tvsent ritter snelle | wurden wol gecleit ### si giengen da si fvnden | sifriden stan ### da wart ein shone grvzen | ein teil mit werchen getan
###### 504 | ### vil chercen was enzvendet | man shancte im lvter tranch ### daz si shiere chomen | er sagts in allen danch ### er sprach ir svlt von hinnen | mit mir vber flvt ### des vant er vil bereite | di helde chven vnt gvt
###### 505 | ### wol drizech hvndert recken | di waren shiere chomen ### vz den wurden der besten | tvsent do genomen ### den brahte man ir helme | vnt ander ir gewant ### want er si fveren wolde | in daz prvnnhilde lant
###### 506 | ### er sprach ir gvte ritter | daz wil ich iv sagen ### ir svlt vil richiv chleider | da ce hove tragen ### want vns da saehen mvezen | vil minnechlichiv wip ### darvmme svlt ir zieren | mit gvter waete den lip
###### 507 | ### an einen morgen frw | hvoben si sich dan ### waz sneller geverten | sifrit do gewan ### si fvrten ros div gvten | vnt herlich gewant ### si chomen ritterliche | in daz prvnhilde lant
###### 508 | ### do stvenden in den cinnen | div minnechlichiv chint ### do sprach div chveneginne | weiz iemen wer di sint ### di ich dort sihe vliezen | so verre vf dem se ### si fverent segle riche | di sint noch wizer danne der sne
###### 509 | ### do sprach der chvenich von rine | ez sint mine man ### di het ich an der verte | hi nahen bi verlan ### di han ich besendet | di sint nv vrove chomen ### der herlichen geste | wart vil groze wargenomen
###### 510 | ### do sah man sifride | vor in einem shepffe stan ### in herlicher waete | vnde ander manigem man ### do sprach div chveneginne | her chvonech ir svlt mir sagen ### sol ich di geste enpfahen | oder sol ich grvezen si verdagen
###### 511 | ### er sprach ir svlt engegen in | fvor den palas gen ### ob wir si gerne sehen | daz si daz wol versten ### do tet div chveneginne | als ir der chvenich geriet ### sifride mit dem grvze | si von den andern shiet
###### 512 | ### man shvf in herberge | vnt behilt in ir gewant ### do was so vil der geste | chomen in daz lant ### daz si sich allenthalben | drvngen in der sharn ### do wolden di vil chvenen | haeim ce lande varn
###### 513 | ### do sprach div chveneginne | ich wold im wesen holt ### der geteiln chvnde | min silber vnt min golt ### min vnt des chveneges gesten | des ich so vile han ### des antwurte danchwart | des chvnich giselheres man
###### 514 | ### vil edliv chvneginne | lat mich der slvozel pflegen ### ich truwe iz so geteilen | sprach der chvene degen ### swaz ich erwerbe shande | di lat min eines sin ### daz er milte waere | daz tet der degen shin
###### 515 | ### do sich hagenen brvder | der slvezel vnderwant ### so manige gabe riche | gap des heldes hant ### swer einer marche gerte | dem wart so vil gegeben ### daz di armen alle | mvsen vroliche leben
###### 516 | ### wol bi hvndert pfvnden | gap er ane zal ### genvge in richer waete | giengen vor dem sal ### di nie davor getrvgen | so helichev kleit ### daz gevriesh div chvnegin | ez was ir waerliche leit
###### 517 | ### do sprach div vrowe here | her chvenich ich hetes rat ### daz iwer chameraere | mir wil der minen wat ### lazen niht beliben | er swendet mir min golt ### der iz noch vnderstvende | dem wold ich iemer wesen holt
###### 518 | ### er git so riche gabe | ia waenet des der degen ### ich habe gesant nach tode | ich wils noch lenger pflegen ### ovch truwe iz wol verswenden | daz mir min vater lie ### so milten chameraere | gewan noch chvneginne nie
###### 519 | ### do sprach von tronege hagene | vrowe iv si geseit ### ez hat der chvenech von rine | golt vnd kleit ### also vil ce gebene | daz wir des haben rat ### daz wir von hinen fveren | iht der prvnnhilde wat
###### 520 | ### nein dvrh mine liebe | sprach div kvenegin ### lazet mich erfvellen | zweinceh leitschrin ### von golde vnt von siden | daz geben sol min hant ### so wir chomen veber | in daz gvntheres lant
###### 521 | ### mit edelem gesteine | ladete man div shrin ### ir selber chameraere | damite mvsen sin ### si ne woldes niht getruwen | dem gvntheres man ### gvnther vnt hagene | darvmb lachen began
###### 522 | ### do sprach div chveneginne | wem laz ich miniv lant ### div sol e bestipfften | min vnt iwer hant ### do sprach der kvnich edele | nv haeizzet her gan ### der iv darzv gevalle | den svl wir voget wesen lan
###### 523 | ### ein ir hohesten mach | div vrowe bi ir sach ### er was ir mvter bruder | zv dem div vrowe sprach ### nv lat ev sin bevolhen | mine bverge vnt ovch div lant ### vnze daz hi rihte | des chvenich gvntheres lant
###### 524 | ### do welt si ir gesindes | zweinzech hvndert man ### di mit ir varen solden | ze bvergonden dan ### zvo ienen tvsent recken | vz nibelvnge lant
###### 523.4 | ### si rihten sich zer verte | man sach si reiten vf den sant
###### 525 | ### si fvrte mit ir dannen | sehs vnt ahzech wip ### darzv wol hvndert maegde | vil shone was in der lip ### sin svomten sich niht langer | si wolden gahen dan ### di si da heime liezen | hey waz der weinen began
###### 526 | ### in tvgentlichen zvehten | si rvmte ir eigen lant ### si chvst ir vrivnt di nahen | di si bi ir vant ### mit gvtem vrlovbe | si chomen vf den se ### zv ir vaterlande | chom div vrowe nimmer me
###### 527 | ### do horte man vf der verte | maniger hande spil ### aller chvercewile | heten si do vil ### do chom in zv ir reise | ein rehter wazzerwint ### si fvren von dem lande | mit vil grozen vrevden sint
###### 528 | ### do ne wolde si den herren | niht minnen vf der vart ### ez wart ir kvrcewile | vnz in ir hus gespart ### ce wormz zv der bvorge | ceiner hochgezit ### da si vil vrevdenriche | chomen mit ir helden sit

<<< Übersicht <<< vorige Seite nächste Seite >>>